#
# spec file for package ntfs-3g (Version 2009.4.4)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           ntfs-3g
Summary:        Linux NTFS-3G userspace filesystem with full write support
Version:        2009.4.4
Release:        3.2.1
Provides:       ntfsprogs-fuse  = 1.13.1
Obsoletes:      ntfsprogs-fuse <= 1.13.1
License:        GPLv2+
Group:          System/Filesystems
Source:         %{name}-%{version}.tar.bz2
Source1:        buildall.sh
Source2:        21-storage-ntfs-3g.fdi
# PATCH-FIX-OPENSUSE ntfs-3g-warnings.patch -- Fix a bunch of warnings that appears because of -Werror. They weren't committed upstream when I sent a patch that contained all our warning fixes (vuntz)
Patch0:         ntfs-3g-warnings.patch
Url:            http://www.ntfs-3g.org
BuildRequires:  ntfsprogs
Requires(post): update-alternatives
Requires(postun): update-alternatives
# The build service fails to build the package because it doesn't really
# understand Requires(post), so use PreReq too (see bnc#439232).
%if %defined suse_version
PreReq:         update-alternatives
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1010
Supplements:    filesystem(ntfs-3g)
%endif

%description
NTFS-3G allows for read/write access to NTFS partitions which can be
shared with Windows XP, Windows Server 2003, Windows 2000 and Windows
Vista.

Limitations:

* No support for journaling. As a result, if the journal is dirty,
   NTFS-3g has to refuse read-write mounts.

* No support for reading/writing compressed and encrypted files

* Only static permissions, set at mount time

Notes:

* Implemented in user space though fuse. It is possible to balance
   performance using normal processor and I/O priorities of the
   ntfs-3g processes.

* NTFS-3g can detect if the filesystem to be mounted has been in use
   by Windows when it hibernated and refuses read-write mount to
   prevent data corruption as a result of Windows resuming with a
   changed filesystem underneath.

Evaluating access permissions and file ownership is handled like in the
Linux FAT and other free Linux NTFS drivers: The access rights for all
files on the mounted partition can be set when mounting the filesystem
and are the same for all files. Requests to change access rights are
silently ignored.

Through the ntfs-3g web site, a version of ntfs-3g with permission
handling (which should be usable but is not released officially) can be
found.

Compared to vanilla ntfs-3g, this version changes the default locale
fallback (when no working locale is defined) from hiding and rejecting
all non-ASCII path names to displaying and expecting UTF-8 encoding in
path names.



Authors:
--------
    Szabolcs Szakacsits

%package devel
License:        GPLv2+
Summary:        Development files and libraries for ntfs-3g
Group:          System/Filesystems
Requires:       %{name} = %{version} glibc-devel

%description devel
Headers and libraries for developing applications that use ntfs-3g
functionality.



Authors:
--------
    Szabolcs Szakacsits

%prep
%setup -q
%patch0 -p1

%build
#
# regarding -Wno-sign-compare - checked with the Szaka: There is one variable
# which is signed and would possibly ok to be unsigned. Any solution to this
# needs to be carefully reviewed and tested, so we do not change the code now:
#
CFLAGS="$RPM_OPT_FLAGS -Wformat -Wformat-security -W -Wno-sign-compare -Werror" \
%configure --exec-prefix=/ --disable-static --with-pic --libdir=/%{_lib} --disable-ldconfig
make %{?jobs:-j%jobs}

%install
%makeinstall
# Move pkg-config to the real libdir
%{__mkdir_p} %{buildroot}%{_libdir}/pkgconfig
%{__mv} -v %{buildroot}/%{_lib}/pkgconfig/*.pc %{buildroot}%{_libdir}/pkgconfig/
%{__ln_s} -v /%{_lib}/$(readlink %{buildroot}/%{_lib}/lib%{name}.so) %{buildroot}%{_libdir}/lib%{name}.so
%{__rm} -v %{buildroot}/%{_lib}/lib%{name}.{so,la}
# Hal stuff for mounting on hotplug.
%{__mkdir_p} %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/
%{__install} -m 644 %{SOURCE2} %{buildroot}%{_datadir}/hal/fdi/policy/10osvendor/21-storage-ntfs-3g.fdi

%clean
rm -rf $RPM_BUILD_ROOT

%check
TESTFS=$(mktemp) || exit 1
/usr/sbin/mkntfs -q -F $TESTFS 3000
src/ntfs-3g.probe --readonly  $TESTFS
src/ntfs-3g.probe --readwrite $TESTFS
rm -v $TESTFS

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog CREDITS NEWS README
%dir %{_datadir}/hal
%dir %{_datadir}/hal/fdi
%dir %{_datadir}/hal/fdi/policy
%dir %{_datadir}/hal/fdi/policy/10osvendor
%{_bindir}/ntfs-3g
%{_bindir}/ntfs-3g.probe
/sbin/mount.ntfs-3g
/%{_lib}/libntfs-3g.so.*
%{_datadir}/hal/fdi/*
%{_mandir}/man8/*
# We already have this, so no need to package it again.
%exclude /usr/share/doc/ntfs-3g/README

%files devel
%defattr(-,root,root,-)
%{_includedir}/ntfs-3g/
%{_libdir}/libntfs-3g.so
%{_libdir}/pkgconfig/libntfs-3g.pc

%post
# If the mount.ntfs group is in automatic mode, then this will also switch all
# symlinks automatically
update-alternatives --install /sbin/mount.ntfs mount.ntfs /sbin/mount.ntfs-3g 10 --slave /usr/share/man/man8/mount.ntfs.8.gz mount.ntfs.8.gz /usr/share/man/man8/mount.ntfs-3g.8.gz
/sbin/ldconfig

%postun
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f /sbin/mount.ntfs-3g ]; then
  update-alternatives --remove mount.ntfs /sbin/mount.ntfs-3g
fi
/sbin/ldconfig

%posttrans
# Workaround old bug in 11.1/11.2 packages that always removed the symlinks in
# %postun. Can be removed during 12.2 development.
if [ ! -f /sbin/mount.ntfs -a -f /sbin/mount.ntfs-3g ]; then
  update-alternatives --install /sbin/mount.ntfs mount.ntfs /sbin/mount.ntfs-3g 10 --slave /usr/share/man/man8/mount.ntfs.8.gz mount.ntfs.8.gz /usr/share/man/man8/mount.ntfs-3g.8.gz
fi

%changelog
* Mon Dec  7 2009 vuntz@opensuse.org
- Rework the update-alternatives part to be really correct, even in
  case of package renaming. Note that we need a %%posttrans to work
  around bugs in previously installed packages.
* Thu Oct 29 2009 crrodriguez@opensuse.org
- fix buggy calls to update-alternatives part of [bnc#544199]
* Sat May  9 2009 crrodriguez@suse.de
- fix -devel package dependencies
- fix suse-filelist-forbidden-devel-in-lib rpmlint error
- avoid possible race condition during %%check
* Tue Apr  7 2009 vuntz@novell.com
- Update to version 2009.4.4:
  + Fix: Mount and system boot could hang if Linux kernel audit was
    enabled.
  + Fix: Volume could be potentially corrupted or the driver
    crashed after a partial write or hardware error.
  + Fix: The driver could crash handling highly fragmented files.
* Fri Mar 27 2009 vuntz@novell.com
- Update to version 2009.3.8:
  + Fix: Some defragmenters reported NTFS-3G created directories
    unmovable.
  + Fix: The Windows NTFS file system checker, CHKDSK, may reported
    "free space marked as allocated in the master file table (MFT)
    bitmap".
  + Fix: The driver may returned "No space left on device" error
    when there was still free space on the NTFS volume.
  + Fix: A file may got corrupted when the STANDARD INFORMATION
    attribute was moved to an extent MFT record. Only the already
    fixed Advanced NTFS-3G Driver had this problem, not the Stable
    NTFS-3G Driver.
  + Change: 10-50%% faster file and directory creation, removal,
    copy, unpackaging performance.
  + Change: 500-1000%% faster mount time. This is mostly noticable
    on multi-TB volumes and embedded devices. Please note, a
    generally 10-20 times faster performing NTFS-3G driver is
    available for embedded devices separately.
  + Change: Improved multi-cluster allocation, non-aligned file
    write performance.
  + Change: Improved volume consistency and recovery if the storage
    device was unsafely detached or powered down.
  + Change: Less disk space usage.
  + New: The version/-V command line option has been added.
- Use makeinstall
* Thu Feb 12 2009 vuntz@novell.com
- Update to version 2009.2.1:
  + The 'recover' and 'norecover' mount options were introduced.
    The former option will cause the driver to recover and repair a
    corrupted or inconsistent NTFS volume if it's possible. The
    default behaviour is 'recover'.
  + The driver could crash when it tried to read a highly
    fragmented file or directory which was either corrupted or it
    was unreadable due to a hardware error.
  + The driver incorrectly returned 'Permission denied' error
    message if a requested extended attribute namespace wasn't
    supported.
  + The lack of file backup timestamp support confused some
    applications on OS X.
  + The user extended attribute namespace is supported by default
    on Linux.
  + A volume having unclean journal file is recovered and mounted
    by default. The 'norecover' mount option can be used to disable
    this behavior.
* Mon Feb  2 2009 mboman@suse.de
- Update to version 2009.1.1:
  + New: Built-in, transparent UTF-8 conversion support.
  + New: Support getting/setting the file creation timestamp on
    OS X.
  + Fix: An extended attribute got corrupted if the new attribute
    size was smaller than the original size.
  + Fix: Memory leaked if an extended attribute or alternate data
    stream couldn't be opened.
  + Fix: Report an error if a filename can not be listed during
    reading a directory.
  + Change: The 'locale=' mount option is not used anymore for
    filename characterset conversion. Instead filenames are always
    converted to UTF-8
- Remove ntfs-3g-utf8-fallback.patch. Fixed differenly upstream
* Fri Jan 23 2009 vuntz@novell.com
- Add back ntfs-3g-warnings.patch, for the warning fixes that were
  not accepted upstream.
* Mon Jan  5 2009 mboman@suse.de
- Update to version 1.5130:
  +  New Advanced NTFS-3G Release
  +  New High-Performance NTFS-3G for Embedded Devices
- Remove ntfs-3g-warnings.patch. Fixed upstream
* Mon Oct 27 2008 ro@suse.de
- changed flavored requires to a simple PreReq
  (the former are not really supported by all tools)
* Mon Oct 27 2008 vuntz@novell.com
- Use Requires(post) and Requires(postun) for update-alternatives,
  to fix potential issues when installing.
* Wed Oct 22 2008 vuntz@novell.com
- Update to version 1.5012:
  + New: Support unlimited file and directory creation.
- Changes from version 1.2812:
  + Fix: A corrupted directory index entry could hang the driver
    instead of returning "I/O error"
- Changes from version 1.2918:
  + Fix: The allocation size of an attribute may got corrupted if
    the attribute size change failed.
  + Fix: An MFT record could leak on big-endian CPUs if adding a
    new attribute failed.
  + Fix: The system log was flooded if a transparently compressed
    or encrypted file was tried to be updated repeatedly.
  + New: Solaris support.
  + New: Libtool-2 support.
  + Change: No external dependency on librt anymore when internal
    FUSE is used (default on Linux).
  + Change: The default compiler is gcc.
  + Change: Internal FUSE further shrank by 10%%.
- Use update-alternatives to provide /sbin/mount.ntfs and the
  relevant man page, /usr/share/man/man8/mount.ntfs.8.gz.
- Add volume.policy.mount_filesystem to the fdi file, since it's
  recommended by upstream and used by other distributions.
- Update ntfs-3g-warnings.patch with a few more warning fixes.
- Add a devel package.
- Tag patches.
- Remove old stuff for non-existing ntfs-3g-permssions.patch.
- Remove lzma BuildRequires.
- Minor cleanup.
* Wed Oct 15 2008 dkukawka@suse.de
- Added fdi file for ntfs-3g. For more info, read comments in the
  new file.
* Mon Jul 14 2008 bk@suse.de
- Update to 1.2712 (maintenance release) to fix a number of issues:
  - A corrupted size directory or a directory over tens of million
    files could have hung the driver
  - Removing alternate data streams and extended attrs leaked memory
  - mount could fail with some mount(8) utilities (e.g. busybox one)
    if the /etc/mtab file didn't exist or was on a read-only fs
  - "I/O error" if the standard file descriptors were closed during
    mount, e.g. via some usage of udev or hotplug
* Thu Jun  5 2008 bk@suse.de
- Update to 1.2531 to fix fs crashes and fs hangs with corrupt NTFS:
  - A corrupted directory could hang the filesystem driver itself.
  - The driver could hang or misbehave when compressed, sparse or
    encrypted file attribute flags were corrupted.
  - The driver could crash when both an MFT attribute offset and
    the allocated bytes were corrupted.
  - Mount could hang if the block allocation map was corrupted.
* Tue May  6 2008 bk@suse.de
- Update to STABLE Version 1.2506 (May 6, 2008):
  - Fix NTFS volume corruption in extremely specific circumstances
  - Fix symlink(2) for size 256 if the old path was over 255 bytes
  - Unprivileged mount fixes: supplementary groups dropped too early
    and make unprivileged mount if /etc/fuse.conf wasn't in shape.
  - No longer pass 'noatime' additionally and unconditionally to mount
- Obsolete ntfsprogs-fuse (to be dropped from ntfsprogs package)
- With ntfsprogs and lzma, this builds in all non-debian repros
* Wed Mar 19 2008 bk@suse.de
- Update to 1.2310:
  - Fix: CHKDSK reported inconsistencies as data and allocation size
    of some special purpose resident unnamed $DATA attribute in the
    index and inode FILE_NAME attributes could be incorrect.
  - Fix: unprivileged mount failed if user had rights for everything
    except the FUSE device file.
  - Fix: the 'dev' and 'suid' mount options weren't useable before
  - Change from ENOTEMPTY to EEXIST on rmdir of non-empty directories
* Mon Mar  3 2008 bk@suse.de
- Add a fix for a crash of the driver with a specific long filename
- Fix support for -odev and -osuid when mounting using /bin/ntfs-3g
* Thu Feb 28 2008 bk@suse.de
- Workaround for build issue with gcc-4.3 (bnc#354113) is obsolete
- Improve treatment of warnings and integrate -Wformat-security
* Mon Feb 18 2008 bk@suse.de
- Update to 1.2216:
  - adds ntfs3-g.probe to check if filesystem is in mountable state
  - fixes "Operation not supported" when deleting huge directories
  - uses specialized integrated libfuse with fixes for suid usage
- Add a temporary workaround to prevent miscompilation with gcc-4.3
- Add a simple functionality check using ntfs-3g.probe to %%check
- Added -Wextra -Werror and fixed the resulting compiler errors
* Wed Sep 26 2007 bk@suse.de
- When called as mount.ntfs-3g and rw mount is not possible because
  the volume is dirty or hibernated, fall back to read-only mounnt
  to allow installation and system boot to succeed (fixes #309074)
* Thu Sep 13 2007 bk@suse.de
- Update to version 1.913
  - Fix too rigid hibernation check which unneccesarily refused mount
  - Free disk space calculation was highly CPU intensive during writes.
    This could reduce write performance severely, especially for huge
    volumes if a file manager or desktop applet regularly polled for
    disk space usage. Change code to O(1), takes ~10ms on a typical
    desktop, and it's now completely independent of the volume size.
  The changes noted below were tested in public release candidate:
  - Significant performance improvement for writing many files,
    typically by 50-1000%% (cp, tar, compile, directory syncronisation)
  - improved the performance of writing multi-GB size files, particulary
    after the creation of many thousands of other files. Previous disk
    space defragmentation is highly adviced for the best possible speed.
    File level defragmentation is not enough.
  - improved concurrent write performance.
* Mon Aug 27 2007 bk@suse.de
- Update to version 1.826:
  * fix: utime() also updated the timestamp of the parent directory
  * fix: ignore the "volume dirty" bit because its real meaning is
    "check the volume". The fact of the real dirtiness is stored in
    the NTFS logfile which is already checked for.
  * new: --disable-library option links libntfs-3g into ntfs-3g
* Fri Aug 10 2007 bk@suse.de
- Update to version 1.810:
  fix: file rename changed the modification time of some files which
    prevented tools like rsync from preserving the timestamp
  fix: unmount (fusermount -u) was denied for an unprivileged user
    who was allowed to mount a block device.
  fix: the driver could hang if there wasn't enough memory during
    reading a large directory
  fix: reading a directory may reporte success when there was an error
  fix: metadata update error was ignored in some very rare cases during
    writing a file
  fix: permissions checking was turned on if umask, fmask and dmask
    was set to the default 000 value.
  change: manual update, added Windows filename compatibility section
  change: lots of logging improvements
* Thu Jul 26 2007 coolo@suse.de
- let yast install the package for ntfs-3g filesystems
* Fri Jul 13 2007 bk@suse.de
- Update to version 1.710:
  change: more troubleshooting hints if a volume can't be mounted
  change: logging improvements
  fix: move, rename and hard link could return "input/output error"
  fix: very rare, recoverable directory corruption
- Do not obsolete ntfsprogs-fuse and do not provide mount.ntfs
  Can coexist with ntfsmount and kernel ntfs module now, but you
  have to use "ntfs-3g" as filesystem type in fstab and mount -t,
  as done in the examples on http://www.ntfs-3g.org/index.html#usage
* Tue Jul  3 2007 bk@suse.de
- Update to version 1.616:
  new: ensure mount works during boot: move binaries to the rootfs
  fix: any kind of file size change failure returned "Operation not permitted"
  fix: a file close failure was not always reported
  fix: an unmount failure was not always reported
  fix: if the $MFT Bitmap wasn't up-to-date file creation always gave "Input/output error"
  fix: converting very long file names to Unicode may have failed
  fix: syslog messages didn't show the low level error detail
* Wed Jun  6 2007 bk@suse.de
- Initial version 1.516, has Obsoletes: ntfsmount-fuse
